==> jakarta-jakartaeetck-8.0.3.zip: jakartaeetck/src/com/sun/ts/tests/ejb30/lite/packaging/war/mbean/interceptor/business/InterceptorOverride34Bean.java <==
/*
 * Copyright (c) 2007, 2018 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

/*
 * $Id$
 */
package com.sun.ts.tests.ejb30.lite.packaging.war.mbean.interceptor.business;

import javax.annotation.ManagedBean;
import javax.interceptor.AroundInvoke;
import javax.interceptor.ExcludeDefaultInterceptors;
import javax.interceptor.InvocationContext;

import com.sun.ts.tests.ejb30.lite.interceptor.common.business.InterceptorBaseBase;
import com.sun.ts.tests.ejb30.lite.interceptor.common.business.InterceptorBeanBase;
import com.sun.ts.tests.ejb30.lite.interceptor.common.business.InterceptorIF;

@ManagedBean
@ExcludeDefaultInterceptors
public class InterceptorOverride34Bean extends InterceptorBeanBase
    implements InterceptorIF {
  private static final String simpleName = "InterceptorOverride34Bean";

  @Override // override the superclass' interceptor method with an interceptor
            // method
  @AroundInvoke
  protected Object intercepInInterceptorBeanBase(InvocationContext inv)
      throws Exception {
    // do not call super
    InterceptorBaseBase.addToHistory(inv, simpleName);
    return inv.proceed();
  }
}

==> jakarta-jakartaeetck-9.0.2.zip: jakartaeetck/src/com/sun/ts/tests/ejb30/lite/packaging/war/mbean/interceptor/business/InterceptorOverride34Bean.java <==
/*
 * Copyright (c) 2007, 2020 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

/*
 * $Id$
 */
package com.sun.ts.tests.ejb30.lite.packaging.war.mbean.interceptor.business;

import jakarta.annotation.ManagedBean;
import jakarta.interceptor.AroundInvoke;
import jakarta.interceptor.ExcludeDefaultInterceptors;
import jakarta.interceptor.InvocationContext;

import com.sun.ts.tests.ejb30.lite.interceptor.common.business.InterceptorBaseBase;
import com.sun.ts.tests.ejb30.lite.interceptor.common.business.InterceptorBeanBase;
import com.sun.ts.tests.ejb30.lite.interceptor.common.business.InterceptorIF;

@ManagedBean
@ExcludeDefaultInterceptors
public class InterceptorOverride34Bean extends InterceptorBeanBase
    implements InterceptorIF {
  private static final String simpleName = "InterceptorOverride34Bean";

  @Override // override the superclass' interceptor method with an interceptor
            // method
  @AroundInvoke
  protected Object intercepInInterceptorBeanBase(InvocationContext inv)
      throws Exception {
    // do not call super
    InterceptorBaseBase.addToHistory(inv, simpleName);
    return inv.proceed();
  }
}
